==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clique no ícone da área de notificação 
ou pressione novamente o atalho para parar de gravar</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Falha ao guardar. Guarde-a no diretório pessoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de ecrã concluída</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>selecione a área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>A guardar o ficheiro da gravação do ecrã, aguarde...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Como os efeitos visuais são desativados durante o processo, a gravação tem de ser interrompida</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de ecrã irá começar em %1 segundos</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aqui</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Captura de ecrã</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Sair/Guardar</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Desenhar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste do tamanho</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Início rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capturar janela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atraso na captura de ecrã</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de ecrã inteiro</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar a altura</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura para baixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar largura à esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar largura à direita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuir altura para baixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuir largura à esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuir largura à direita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar a gravação</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Gravação</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Desfocar</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Som ligado</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Som do sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Som desligado</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostrar pressão da tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ocultar pressão da tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam ligada</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam desligada</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostrar clique</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Guardar em</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Ambiente de trabalho</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar cursor</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostrar cursor</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajustar a área de gravação dentro de %1*%2 para obter um melhor efeito de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Gravações</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clique no ícone da área de notificação 
ou pressione novamente o atalho para parar de gravar</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Não rodar o seu ecrã durante a gravação</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Falha ao guardar. Guarde-a no diretório pessoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de ecrã concluída</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>selecione a área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>A guardar o ficheiro da gravação do ecrã, aguarde...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Como os efeitos visuais são desativados durante o processo, a gravação tem de ser interrompida</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>A captura de ecrã foi guardada no álbum</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>A captura de ecrã falhou.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de ecrã irá começar em %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obter ajuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Falha ao tirar uma captura de ecrã contínua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Atingiu o fundo da área de rolagem</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Atingiu o comprimento máximo</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar a área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Deslize a roda rato ou clique para tirar um screenshot com função deslizar </translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Diminuir a velocidade de deslizar</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Área inválida, clique para</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aqui</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Captura de ecrã</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Sair/Guardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste do tamanho</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Início rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capturar janela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atraso na captura de ecrã</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de ecrã inteiro</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar a altura</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura para baixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar largura à esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar largura à direita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuir altura para baixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuir largura à esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuir largura à direita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar a gravação</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Gravação</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Afixar capturas de ecrã</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Desfocar</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Som ligado</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Som do sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Som desligado</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostrar pressão da tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ocultar pressão da tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam ligada</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam desligada</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostrar clique</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Guardar em</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Ambiente de trabalho</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar cursor</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostrar cursor</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Afixar capturas de ecrã</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajustar a área de gravação dentro de %1*%2 para obter um melhor efeito de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>A gravação do ecrã não é atualmente suportada</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>
